package com.yunos.cmns.sdkdemo;

import android.Manifest;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Handler;
import android.os.Parcel;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.cmns.service.demo.myapplication.R;
import com.yunos.cmns.api.CMNSErrorCode;
import com.yunos.push.PushClient;
import com.yunos.push.api.ErrorCode;
import com.yunos.push.api.listener.PushConnectionListener;
import com.yunos.push.api.listener.PushGetDeviceTokenListener;
import com.yunos.push.api.listener.PushSendMessageListener;
import com.yunos.push.api.listener.PushUpdateTagListener;


public class MainActivity extends AppCompatActivity {
    private static final String TAG = "[PushDemo] Activity";
    private Handler mHandler = new Handler();

    void showNetworkPermissionDialog() {
        if (!NetworkPermissionConfig.getInstance().getUserPermission()) {
            AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity.this);
            builder.setMessage("是否允许应用访问网络？");
            builder.setPositiveButton("确认", new AlertDialog.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    dialog.dismiss();
                    NetworkPermissionConfig.getInstance().singal();
                }
            });
            builder.setNegativeButton("取消", new AlertDialog.OnClickListener() {
                @Override
                public void onClick(DialogInterface dialog, int which) {
                    dialog.dismiss();
                    MainActivity.this.finish();
                }
            });
            builder.create().show();
        }
    }

    void initWidgetEvent() {
        // dynamic request READ_PHONE_STATE & WRITE_EXTERNAL_STORAGE permission on Android5.0 or above.
        ActivityCompat.requestPermissions(this, new String[] {Manifest.permission.READ_PHONE_STATE, Manifest.permission.WRITE_EXTERNAL_STORAGE}, 0);

        findViewById(R.id.btnIsConnected).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Toast.makeText(MainActivity.this, "connected: " +
                        PushClient.getInstance().isConnected(), Toast.LENGTH_SHORT).show();
            }
        });

        findViewById(R.id.btnConnect).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().connect(new PushConnectionListener() {
                    @Override
                    public void onConnect(final int errorCode) {
                        mHandler.post(new Runnable() {
                            @Override
                            public void run() {
                                if (errorCode == 0) {
                                    Toast.makeText(MainActivity.this, "connect success", Toast.LENGTH_SHORT).show();
                                } else {
                                    Toast.makeText(MainActivity.this, "connect failed: " + errorCode, Toast.LENGTH_SHORT).show();
                                }
                            }
                        });
                    }
                });
            }
        });

        final Button btnGetDeviceToken = (Button) findViewById(R.id.btnGetDeviceToken);
        btnGetDeviceToken.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().getDeviceToken(new PushGetDeviceTokenListener() {
                    @Override
                    public void onGetDeviceToken(final int errorCode, final String token) {
                        mHandler.post(new Runnable() {
                            @Override
                            public void run() {
                                Toast.makeText(MainActivity.this, "getDeviceToken errorCode:" + errorCode + "\ntoken: " + token, Toast.LENGTH_SHORT).show();
                            }
                        });
                    }
                });
            }
        });

        final EditText editTag = (EditText) findViewById(R.id.editTag);

        final Button btnSetTag = (Button) findViewById(R.id.btnSetTag);
        btnSetTag.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().setTag(editTag.getText().toString(), new PushUpdateTagListener() {
                    @Override
                    public void onUpdateTag(final int errorCode) {
                        Log.i(TAG, "update tag with error code:" + errorCode);
                        mHandler.post(new Runnable() {
                            @Override
                            public void run() {
                                if (errorCode == CMNSErrorCode.ERROR_OK) {
                                    Toast.makeText(MainActivity.this, "setTag success", Toast.LENGTH_SHORT).show();
                                } else {
                                    Toast.makeText(MainActivity.this, "setTag failed: " + errorCode, Toast.LENGTH_SHORT).show();
                                }
                            }
                        });
                    }
                });
            }
        });

        final Button btnDelTag = (Button) findViewById(R.id.btnDelTag);
        btnDelTag.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().delTag(editTag.getText().toString(), new PushUpdateTagListener() {
                    @Override
                    public void onUpdateTag(final int errorCode) {
                        Log.i(TAG, "delete tag with error code:" + errorCode);
                        mHandler.post(new Runnable() {
                            @Override
                            public void run() {
                                if (errorCode == ErrorCode.ERROR_OK) {
                                    Toast.makeText(MainActivity.this, "delTag success", Toast.LENGTH_SHORT).show();
                                } else {
                                    Toast.makeText(MainActivity.this, "delTag failed: " + errorCode, Toast.LENGTH_SHORT).show();
                                }
                            }
                        });
                    }
                });
            }
        });

        final EditText editMessage = (EditText) findViewById(R.id.editMessage);

        final Button btnSendMessage = (Button) findViewById(R.id.btnSendMessage);
        btnSendMessage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().sendMessage("", editMessage.getText().toString());
            }
        });

        final Button btnSendMessageWithReply = (Button) findViewById(R.id.btnSendMessageWithReply);
        btnSendMessageWithReply.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                PushClient.getInstance().sendMessageWithReply("", editMessage.getText().toString(), new PushSendMessageListener() {
                    @Override
                    public void onSendMessage(final int errorCode) {
                        Log.i(TAG, "send message with error code:" + errorCode);
                        mHandler.post(new Runnable() {
                            @Override
                            public void run() {
                                if (errorCode == CMNSErrorCode.ERROR_OK) {
                                    Toast.makeText(MainActivity.this, "sendMessageWithReply success", Toast.LENGTH_SHORT).show();
                                } else {
                                    Toast.makeText(MainActivity.this, "sendMessageWithReply failed: " + errorCode, Toast.LENGTH_SHORT).show();
                                }
                            }
                        });
                    }
                });
            }
        });
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        initWidgetEvent();
        showNetworkPermissionDialog();
    }
}
